% function grasp_auto(objects, file)
% Grasps objects autonomously after training
% Example: grasp_auto([1:10], 0) % performs grasps of objects 1 to 10
% Example: grasp_auto([2 3 5 6], 0) % performs grasps of objects 2, 3, 5, 6
% There are up to 38 objects
% If file==0, the results are animated
% If a file indentifier is given, the results are stored

function grasp_auto(objects_selected, file)

% required paths
path(path, '../functions');

% loop for all objects selected
for i = 1:length(objects_selected)
      
   % loads the object to be grasped
   [x, y, xc, yc] = load_object(objects_selected(i));
       
   % object contours
   [numtotal, ncont, npoints, c, p] = object_contours(x);

   % limits of the robot gripper
   [lim_max, lim_min]=gripper_2jaw_data;

   % default values for results
   [candidate, graspset, num, valid, optim, ap, d1, d2, d3, q1, q2, q3] = default_values();
  
   % STEP 1: local attributes are used to detect candidate contact points
   [candidate, dist_loc, ang_loc] = testlocal(x, y, xc, yc, 2);
     
   % STEP 2: sets of 2 points reachable with the 2 jaw robot gripper
   if sum(candidate)>0
      [graspset, num] = reachable2(candidate, x, y, 2, lim_max, lim_min, numtotal);    
   end
  
   % STEP 3: global attributes are used to detect candidate point sets
   if num>0
      [valid, dist_glo, ang_glo] = testglobal(graspset, num, x, y, xc, yc, 2);
      if sum(valid)==0
         % no preferable sets, all sets are considered equal for next step
         valid(1:length(valid))=1;     
      end  
   end

   % STEP 4: select, among the valid sets, the most similar to an example
   if num>0
      [optim, dist_ej] = closestset(valid, graspset, num, x, y, xc, yc, 2, dist_loc, ang_loc, dist_glo, ang_glo);
   end
    
   % robot and gripper configuration capable of reaching the contact set
   if optim>0
      [d1, d2, q1, q2, q3] = robotconfig2(x, y, num, valid, optim, graspset);
   end

   if file==0
      % animation of results
      stop = showresult(2, x, y, xc, yc, candidate, graspset, num, valid, optim, 0, d1, d2, 0, q1(1), q2(1), q3(1));    
   else
      % results are stored in a file
      storeresult(file, objects_selected(i), x, y, graspset, valid, optim);
      stop = 0;
   end
         
   % if the user asks to stop, no more grasps are performed
   if stop==-2
       break;
   end
   
end

